==> delta_core-1.1.2.tar.gz: delta_core-1.1.2/delta/run/job/builder/python_builder.py <==
import dataclasses
import io
import os
import re
from typing import List

from delta.manifest.parser import Model
from delta.run.job.builder import JobBuilder


@dataclasses.dataclass
class SoftwarePackage:
    name: str
    version: str


class PythonRunner(JobBuilder):
    def __init__(self, model: Model):
        self.model = model

    @staticmethod
    def __build_run_command(
            apt_requirements: List[SoftwarePackage],
            pip_requirements: List[SoftwarePackage],
            pip_requirement_files: List[str],
    ) -> str:
        run = []
        if apt_requirements:
            segment = " ".join(
                map(lambda x: f"{x.name}={x.version}", apt_requirements)
            )
            run.append("apt-get update")
            run.append(f"apt-get install --no-install-recommends -y {segment}")
            run.append(f"apt-get clean")
            run.append(f"rm -rf /var/apt/lists/*")

        if pip_requirement_files:
            segment = "pip install --no-cache-dir"
            for requirement_file in pip_requirement_files:
                segment = f"{segment} -r /root/{requirement_file}"
            run.append(segment)

        if pip_requirements:
            segment = " ".join(
                map(lambda x: f"{x.name}=={x.version}", pip_requirements)
            )
            run.append(f"pip install --no-cache-dir {segment}")
        return " ;\\\n\t".join(run)

    def generate_dockerfile(self) -> str:
        params = self.model.parameters
        with io.StringIO() as buf:
            buf.write(f"FROM python:{params['pythonVersion']}-slim\n")
            # copying requirement files if necessary
            if params.get("pipRequirementFiles"):
                requirement_files = " ".join(params["pipRequirementFiles"])
                buf.write(f"COPY {requirement_files} /root/\n")
            # prepare command
            apt_requirements = [
                SoftwarePackage(**e) for e in params.get("aptRequirements", [])
            ]
            pip_requirements = [
                SoftwarePackage(**e) for e in params.get("pipRequirements", [])
            ]
            # FIXME remove this when no additional copy will no be necessary
            pip_requirements.append(SoftwarePackage(
                name="awscli", version="1.32.20"
            ))
            if params.get("environment"):
                for key, value in params.get("environment", {}).items():
                    buf.write(f'ENV {key}={value}\n')
            run_command = self.__build_run_command(
                apt_requirements=apt_requirements,
                pip_requirements=pip_requirements,
                pip_requirement_files=params.get("pipRequirementFiles", []),
            )
            if run_command:
                buf.write(f"RUN {run_command}\n")
            buf.write(f"COPY . /delta\n")
            buf.write(f"WORKDIR /delta\n")
            return buf.getvalue()

    def build_command(self, **kwargs) -> str:
        cmd_pattern = self.model.parameters["command"]
        evaluated_cmd = []
        for cmd_segment in cmd_pattern.split(" "):
            m = re.match(
                r"\$\(([a-z][A-Za-z0-9_-]*)(\.[a-z][A-Za-z0-9_-]*)*\)",
                cmd_segment
            )
            if m:
                keys = m.group()[2:-1].split(".")
                model_part = getattr(self.model, keys[0])
                model_part = model_part[keys[1]]
                value = kwargs[keys[0]].get(keys[1])
                placeholder = self.placeholder_factory(model_part, value)
                evaluated_cmd.append(placeholder.evaluate())
            else:
                evaluated_cmd.append(cmd_segment)
        return " ".join(evaluated_cmd)

==> delta_core-1.2.0.tar.gz: delta_core-1.2.0/delta/run/job/builder/python_builder.py <==
import dataclasses
import io
import os
import re
from typing import List

from delta.manifest.parser import Model
from delta.run.job.builder import JobBuilder


@dataclasses.dataclass
class SoftwarePackage:
    name: str
    version: str


class PythonRunner(JobBuilder):
    def __init__(self, model: Model):
        self.model = model

    @staticmethod
    def __build_run_command(
            apt_requirements: List[SoftwarePackage],
            pip_requirements: List[SoftwarePackage],
            pip_requirement_files: List[str],
    ) -> str:
        run = []
        if apt_requirements:
            segment = " ".join(
                map(lambda x: f"{x.name}={x.version}", apt_requirements)
            )
            run.append("apt-get update")
            run.append(f"apt-get install --no-install-recommends -y {segment}")
            run.append(f"apt-get clean")
            run.append(f"rm -rf /var/apt/lists/*")

        if pip_requirement_files:
            segment = "pip install --no-cache-dir"
            for requirement_file in pip_requirement_files:
                segment = f"{segment} -r /root/{requirement_file}"
            run.append(segment)

        if pip_requirements:
            segment = " ".join(
                map(lambda x: f"{x.name}=={x.version}", pip_requirements)
            )
            run.append(f"pip install --no-cache-dir {segment}")
        return " ;\\\n\t".join(run)

    def generate_dockerfile(self) -> str:
        params = self.model.parameters
        with io.StringIO() as buf:
            buf.write(f"FROM python:{params['pythonVersion']}-slim\n")
            # copying requirement files if necessary
            if params.get("pipRequirementFiles"):
                requirement_files = " ".join(params["pipRequirementFiles"])
                buf.write(f"COPY {requirement_files} /root/\n")
            # prepare command
            apt_requirements = [
                SoftwarePackage(**e) for e in params.get("aptRequirements", [])
            ]
            pip_requirements = [
                SoftwarePackage(**e) for e in params.get("pipRequirements", [])
            ]
            # FIXME remove this when no additional copy will no be necessary
            pip_requirements.append(SoftwarePackage(
                name="awscli", version="1.32.20"
            ))
            if params.get("environment"):
                for key, value in params.get("environment", {}).items():
                    buf.write(f'ENV {key}={value}\n')
            run_command = self.__build_run_command(
                apt_requirements=apt_requirements,
                pip_requirements=pip_requirements,
                pip_requirement_files=params.get("pipRequirementFiles", []),
            )
            if run_command:
                buf.write(f"RUN {run_command}\n")
            buf.write(f"COPY . /delta\n")
            buf.write(f"WORKDIR /delta\n")
            return buf.getvalue()

    def build_command(self, secure: bool = False, **kwargs) -> str:
        cmd_pattern = self.model.parameters["command"]
        evaluated_cmd = []
        for cmd_segment in cmd_pattern.split(" "):
            m = re.match(
                r"\$\(([a-z][A-Za-z0-9_-]*)(\.[a-z][A-Za-z0-9_-]*)*\)",
                cmd_segment
            )
            if m:
                keys = m.group()[2:-1].split(".")
                model_part = getattr(self.model, keys[0])
                model_part = model_part[keys[1]]
                value = kwargs[keys[0]].get(keys[1])
                placeholder = self.placeholder_factory(model_part, value)
                evaluated_cmd.append(placeholder.evaluate(secure))
            else:
                evaluated_cmd.append(cmd_segment)
        return " ".join(evaluated_cmd).strip().replace("  ", " ")
